Range-v3: ranges::v3::merge_move_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::merge_move_fn Struct Reference
Algorithms

## Public Member Functions
template<typename I0 , typename S0 , typename I1 , typename S1 , typename O , typename C = ordered_less, typename P0 = ident, typename P1 = ident, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(IteratorRange< I0, S0 >()&& IteratorRange< I1, S1 >()&& MoveMergeable< I0, I1, O, C, P0, P1 >()), int >::type = 0>
tagged_tuple< tag::in1(I0), tag::in2(I1), tag::out(O)> | operator() (I0 begin0, S0 end0, I1 begin1, S1 end1, O out, C pred_=C{}, P0 proj0_=P0{}, P1 proj1_=P1{}) const
template<typename Rng0 , typename Rng1 , typename O , typename C = ordered_less, typename P0 = ident, typename P1 = ident, typename I0 = range_iterator_t<Rng0>, typename I1 = range_iterator_t<Rng1>, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Range< Rng0 >()&& Range< Rng1 >()&& MoveMergeable< I0, I1, O, C, P0, P1 >()), int >::type = 0>
tagged_tuple< tag::in1(range_safe_iterator_t< Rng0 >), tag::in2(range_safe_iterator_t< Rng1 >), tag::out(O)> | operator() (Rng0 &&rng0, Rng1 &&rng1, O out, C pred=C{}, P0 proj0=P0{}, P1 proj1=P1{}) const